import 'package:country_codes/country_codes.dart';
import 'package:get/get.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:location/location.dart';

import 'rabbit_config_controller.dart';

class LocationController {
  final RabbitConfigController _config = Get.find(tag: 'rdc_flutter_sdk_2');
  late bool isGranted;
  late bool serviceEnabled;
  bool nonPrecise = false;
  LocationData? position;

  var localeCountry = '';
  var localeLang = '';

  Future<LocationController> init() async {
    await getPosition();
    await getLocale();
    return this;
  }

  Future<void> getLocale() async {
    await CountryCodes.init();
    var deviceLocale = CountryCodes.getDeviceLocale();
    if (deviceLocale == null) return;

    localeCountry = deviceLocale.countryCode ?? '';
    localeLang = deviceLocale.languageCode;
  }

  Future<void> getPosition() async {
    Location location = Location();

    serviceEnabled = await location.serviceEnabled();
    if (!serviceEnabled) return;

    isGranted = await Permission.location.isGranted;
    if (!isGranted) return;

    try {
      position = await location
          .getLocation()
          .timeout(Duration(seconds: _config.locationTimeout), onTimeout: () {
        position = LocationData.fromMap({'latitude': 0.0, 'longitude': 0.0});
        return Future.value(position);
      });
    } catch (e) {
      position = LocationData.fromMap({'latitude': 0.0, 'longitude': 0.0});
    }
  }
}
